import{C as t,E as d,K as f,a as i,M as l,c as y,P as b,R as c,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.77323eb8.js";import"./outputWidgets.16ea2802.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="1d8097fa-1ff0-48ed-8946-5f752ba8f74e",e._sentryDebugIdIdentifier="sentry-dbid-1d8097fa-1ff0-48ed-8946-5f752ba8f74e")}catch{}})();export{t as CancellationTokenSource,d as Emitter,f as KeyCode,i as KeyMod,l as MarkerSeverity,y as MarkerTag,b as Position,c as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.db16ab97.js.map
