import{eN as t,eO as r}from"./outputWidgets.16ea2802.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="8d6a1266-4ca4-4b12-9d30-64bb22af8126",e._sentryDebugIdIdentifier="sentry-dbid-8d6a1266-4ca4-4b12-9d30-64bb22af8126")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.b25dd7bb.js.map
