import{V as a}from"./outputWidgets.16ea2802.js";import{c as s,d as f}from"./index.956a9344.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="84fa7859-cc2d-420e-bf69-ff6dd5df89bc",e._sentryDebugIdIdentifier="sentry-dbid-84fa7859-cc2d-420e-bf69-ff6dd5df89bc")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:i,TimePicker:m,QuarterPicker:o,RangePicker:c}=s(f),y=a(n,{WeekPicker:r,MonthPicker:t,YearPicker:i,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.62116a85.js.map
