import{g as c}from"./api.b2e85935.js";import{P as m}from"./Passwordless.ff2e0011.js";import{a as p}from"./asyncComputed.47e4eb5e.js";import{W as u}from"./WidgetsFrame.e3d450b5.js";import{d as l,eA as f,eB as _,b as d,ev as y,e as g,u as s,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.16ea2802.js";import"./runnerData.21139cb1.js";import"./url.4e0b2dd1.js";import"./index.4c4f5011.js";import"./pubsub.af6aba89.js";import"./icons.ab8b614a.js";import"./CircularLoading.b7a86073.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="dd49446a-1c01-492b-8659-a0811be56816",e._sentryDebugIdIdentifier="sentry-dbid-dd49446a-1c01-492b-8659-a0811be56816")}catch{}})();const x={class:"login"},I=l({__name:"Login",setup(e){const t=f(),a=_(),{result:o}=p(c),i=()=>{const{redirect:r,...n}=a.query;if(r){t.push({path:r,query:n,params:a.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(d(),y("div",null,[g("div",x,[s(o)?(d(),b(u,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.e365ee41.js.map
