import{V as s,f as d,Q as p}from"./outputWidgets.16ea2802.js";import{B as c,b as i}from"./Base.5893a998.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="ab7da368-c7d4-461d-b671-8ace9c6c1d6a",a._sentryDebugIdIdentifier="sentry-dbid-ab7da368-c7d4-461d-b671-8ace9c6c1d6a")}catch{}})();const f=()=>p(i(),["component"]),r=(a,e)=>{let{slots:t,attrs:o}=e;const n=s(s(s({},a),{component:"div"}),o);return d(c,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=f();const g=r;export{g as A};
//# sourceMappingURL=Paragraph.069ce9fd.js.map
