import{B as s}from"./Base.5893a998.js";import{A as t}from"./Link.0ffd783c.js";import{A as o}from"./Paragraph.069ce9fd.js";import{A as r}from"./Text.f1c3ccc8.js";import{A as i}from"./Title.3acc75f2.js";import{T as e}from"./Typography.1157fa19.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="9466b0ae-7101-4ac5-aa13-1b677860d5d9",a._sentryDebugIdIdentifier="sentry-dbid-9466b0ae-7101-4ac5-aa13-1b677860d5d9")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=t;e.Base=s;e.install=function(a){return a.component(e.name,e),a.component(e.Text.displayName,r),a.component(e.Title.displayName,i),a.component(e.Paragraph.displayName,o),a.component(e.Link.displayName,t),a};
//# sourceMappingURL=index.f6a07886.js.map
