import{cz as d}from"./outputWidgets.16ea2802.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="02133045-6897-4b4d-9afd-370a08c37012",e._sentryDebugIdIdentifier="sentry-dbid-02133045-6897-4b4d-9afd-370a08c37012")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.653fd751.js.map
