import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.9f194304.js";import{K as f,P as d,L as b}from"./repository.46fef0e8.js";import{d as l,b as c,ev as u,f as p,u as r}from"./outputWidgets.16ea2802.js";import{u as g}from"./index.4c4f5011.js";import{a as y}from"./asyncComputed.47e4eb5e.js";import{g as _}from"./api.b2e85935.js";import"./Text.f1c3ccc8.js";import"./Base.5893a998.js";import"./Typography.1157fa19.js";import"./index.f6a07886.js";import"./Link.0ffd783c.js";import"./Paragraph.069ce9fd.js";import"./Title.3acc75f2.js";import"./index.10ef2cfb.js";import"./ArrowRightOutlined.08fa31dd.js";import"./api.69233102.js";import"./index.cf4c23b9.js";import"./icons.ab8b614a.js";import"./index.124f0a07.js";import"./ant-design.cef67a1f.js";import"./index.1d0a03a3.js";import"./Modal.cc91ab2e.js";import"./index.abf95935.js";import"./index.b25dd7bb.js";import"./index.95e25fbe.js";import"./CollapsePanel.905f74e9.js";import"./Form.8992253c.js";import"./hasIn.4309230e.js";import"./Timeline.da7a26bd.js";import"./index.660b3e74.js";import"./index.afe70fc1.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.412d628c.js";import"./workspaces.b436380b.js";import"./runnerData.21139cb1.js";import"./url.4e0b2dd1.js";import"./record.a44a4b35.js";import"./pubsub.af6aba89.js";import"./scripts.e744daca.js";import"./envVars.ccb1d9ba.js";import"./ExpandOutlined.7e131d5d.js";import"./Card.bcc2cb4a.js";import"./TabPane.a84ab4ec.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="afcb875f-086d-495d-ba6f-03aff5bdc16a",o._sentryDebugIdIdentifier="sentry-dbid-afcb875f-086d-495d-ba6f-03aff5bdc16a")}catch{}})();const fo=l({__name:"Kanban",setup(o){const t=new d(g),e=new b("kanban"),{result:a}=y(_);return(k,w)=>{var i,n,m;return c(),u("div",null,[p(s,{"brand-name":((i=r(a))==null?void 0:i.brandName)||((n=r(a))==null?void 0:n.name),"logo-url":(m=r(a))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(f,{"kanban-repository":r(t),storage:r(e)},null,8,["kanban-repository","storage"])])}}});export{fo as default};
//# sourceMappingURL=Kanban.8554c284.js.map
