import{d as m,eB as c,u as e,b as d,c as u,ev as y,f as a,w as o,bv as _,ar as p,ex as g,e as b,eD as x}from"./outputWidgets.16ea2802.js";import"./router.84d64d32.js";import"./index.d6d761a8.js";import{O as w}from"./organization.0afc5f14.js";import{a as k}from"./asyncComputed.47e4eb5e.js";import{A}from"./Title.3acc75f2.js";import{A as B}from"./index.124f0a07.js";import{A as h}from"./index.660b3e74.js";import{A as C}from"./Text.f1c3ccc8.js";import{C as v}from"./Card.bcc2cb4a.js";import"./Form.8992253c.js";import"./hasIn.4309230e.js";import"./index.cf4c23b9.js";import"./record.a44a4b35.js";import"./pubsub.af6aba89.js";import"./Base.5893a998.js";import"./Typography.1157fa19.js";import"./TabPane.a84ab4ec.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="0e899460-b9aa-48ba-8794-f650c15231ee",t._sentryDebugIdIdentifier="sentry-dbid-0e899460-b9aa-48ba-8794-f650c15231ee")}catch{}})();const D={key:1},I={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},W=m({__name:"Billing",setup(t){const n=c().params.organizationId,{loading:l,result:f}=k(()=>w.get(n));return(z,N)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",D,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(A),{level:3},{default:o(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(h),{style:{"margin-top":"0"}}),a(e(v),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),b("div",I,x((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{W as default};
//# sourceMappingURL=Billing.c509697f.js.map
