import{S as p}from"./Sidebar.dcf93be1.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.5f6a65e9.js";import{L as d,M as l,N as u}from"./icons.ab8b614a.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.16ea2802.js";import{a as w}from"./asyncComputed.47e4eb5e.js";import"./router.84d64d32.js";import"./index.d6d761a8.js";import{O as z}from"./organization.0afc5f14.js";import{B as h}from"./BaseLayout.4c45db9d.js";import"./index.abf95935.js";import"./logo.084e5d7c.js";import"./Text.f1c3ccc8.js";import"./Base.5893a998.js";import"./Typography.1157fa19.js";import"./index.10ef2cfb.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.8992253c.js";import"./hasIn.4309230e.js";import"./index.cf4c23b9.js";import"./record.a44a4b35.js";import"./pubsub.af6aba89.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="19c7085c-e324-479d-b5d3-0406f643a0e0",o._sentryDebugIdIdentifier="sentry-dbid-19c7085c-e324-479d-b5d3-0406f643a0e0")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:t}=w(()=>z.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.eabfefc9.js.map
