import"./outputWidgets.16ea2802.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="af914044-0f79-4148-ab0d-95be1038dade",e._sentryDebugIdIdentifier="sentry-dbid-af914044-0f79-4148-ab0d-95be1038dade")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.4e0b2dd1.js.map
